@@ -2,8 +2,8 @@
 #
 # Copyright (C) Zenoss, Inc. 2013, all rights reserved.
 #
-# This content is made available according to terms specified in
-# License.zenoss under the directory where your Zenoss product is installed.
+# This content is made available according to terms specified in the LICENSE
+# file at the top-level directory of this package.
 #
 ##############################################################################
 
@@ -87,11 +87,11 @@ class WinrmClient(object):
         defer.returnValue(items)
 
 
-def create_winrm_client(hostname, username, password):
+def create_winrm_client(hostname, auth_type, username, password):
     """
     Constructs a WinRM client with the default response handler.
     """
-    sender = RequestSender(hostname, username, password)
+    sender = RequestSender(hostname, auth_type, username, password)
     return WinrmClient(sender, SaxResponseHandler())
 
 
